==> ui-framework-elements-4.12.9-sources.jar: gen/displays/templates/PropertyMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import PropertyMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import PropertyMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class PropertyMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new PropertyMoldNotifier(this);
		this.requester = new PropertyMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a187503373" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a112220853" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a112220853.a1423203302" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a112220853.a_2105908595" format="h6" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a112220853.a1423405205" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a312111403" format="body2" mode="normal" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1677853989" layout="horizontal">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1677853989.a_1382425476" format="body2 valuesLabelFormat" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1677853989.a_406242195" format="body2 widgetType" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1677853989.a1145227608" format="body2" mode="normal">
					</UiText>
				</UiBlock>
			</UiBlock>
		);
	}


}

export default withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold));
DisplayFactory.register("PropertyMold", withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold)));

==> ui-framework-elements-4.17.10-sources.jar: gen/displays/templates/PropertyMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import PropertyMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import PropertyMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class PropertyMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new PropertyMoldNotifier(this);
		this.requester = new PropertyMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a187503373" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1373836399" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1373836399.a_1004836576" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1373836399.a_382426855" format="h6" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1373836399.a_1004634673" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a312111403" format="body2" mode="normal" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2005281877" layout="horizontal">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2005281877.a1484297020" format="body2 valuesLabelFormat" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2005281877.a49189677" format="body2 widgetType" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2005281877.a_1791173992" format="body2" mode="normal">
					</UiText>
				</UiBlock>
			</UiBlock>
		);
	}


}

export default withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold));
DisplayFactory.register("PropertyMold", withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold)));
